#!/usr/local/bin/perl -w

#### LAST UPDATED: Oct19, 2002 ####
# join.pl version 0.1

###########################################################################
#
# This program concatenates those lines of the senseval data which are 
# part of the same sentence but separated by new line characters.
# The lines to be concatenated should be specified in the file LINES.
# 
# USAGE : join.pl [OPTIONS] LINES SOURCE DESTINATION
#
###########################################################################

# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# START OF PROGRAM
use Getopt::Long;

# Check if any options specified
GetOptions("version", "help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }

# Print help if asked
if ( $help )
{
    &help();
    exit;
}
# if version has been requested, show version
if ( defined $opt_version )
{
    $opt_version = 1;
    &showVersion();
    exit;
}

# Check if command line options have been provided
# If not print usage information
if ( $#ARGV < 2 )
{
    &usage();
    exit;
}

# Accept command line arguements
$lnnofl = shift(@ARGV);
$evalfl = shift(@ARGV);
$destfl = shift(@ARGV);

if(-e $destfl)
{
    print "Destination file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y")
    {
        print "Overwriting the file.\n";
    }
    else
    {
        exit;
    }
}

# Open corresponding files
open(LNO, "<$lnnofl") or die "could not open file ";
open(EVAL, "<$evalfl") or die "could not open file ";
open(OP, ">$destfl") or die "could not open file ";

# Initialise Array size counter
$i=0;
# Read lines from LINES file, line by line
while($lno = <LNO>)
{
    # Read next line if present one is blank
    if($lno =~ /^\s*$/)
    { next; }
    # Remove newline character
    chomp($lno);
    # Store line number in array	
    $arr[$i] = "$lno";
    # increment counter
    $i++;
}

# Sort array in ascending order
foreach $arrlnno(sort {$a <=> $b} @arr)
{
    # Read lines from SOURCE file
	while($eval = <EVAL>)
	{
	    # Increment source file line counter
	    $evallno++;
	    # Check if newline is to be removed from end of present line
		if( $evallno == $arrlnno)
		{
		    # Remove new line
		    chomp($eval);
		    # Print line to DESTINATION
		    print OP "$eval ";
		    last;
		}
	    # Print file to destination
	    print OP $eval;
	}
}

# Print the remaining lines of the SOURCE file
while($eval = <EVAL>)
{
    print OP $eval;
}

# Subroutine to print help message
sub help
{
    print "Usage: join.pl [OPTIONS] LINES SOURCE DESTINATION\n\n";
    print "This program concatenates lines of the SOURCE file as specified in the LINES file. The LINES file has a list of line numbers of the lines which are split. Each line number is separated by a new line character. The result is stored in the DESTINATION file.\n\n"; 
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n";
    print "  --version          Prints the version number.\n\n";
}

sub usage
{
    print "Usage: join.pl [OPTIONS] LINES SOURCE DESTINATION\n";
    AskHelp();
}
# Message describing way to get help
sub AskHelp
{
    print "Type join.pl --help for help.\n";
}
# function to output the version number
sub showVersion
{
    print STDERR "join.pl      -        version 0.1\n";
    print STDERR "A component of refine version 0.1\n";
    print STDERR "Copyright (C) 2000-2003, Saif Mohammad Ted Pedersen\n";
}

